import boto3

from bluecanary.plugins.plugin_base_class import PluginBaseClass
from bluecanary.utilities import throttle


class DiskUtilizationAlarm(PluginBaseClass):

    __nonstandard_kwargs__ = ['MountPath']

    @throttle()
    def get_dimensions(self, identifier, **kwargs):
        cloudwatch_client = self.__boto3__.client('cloudwatch')

        response = cloudwatch_client.list_metrics(
            Namespace='System/Linux',
            MetricName='DiskSpaceUtilization',
            Dimensions=[{'Name': 'InstanceId', 'Value': identifier}]
        )

        lists_of_dimensions = [
            response_group['Dimensions']
            for response_group in response['Metrics']
        ]

        for dimensions in lists_of_dimensions:
            if self._get_mount_path(dimensions) == kwargs.get('MountPath'):
                return dimensions

        # Fail to find any Metrics associated with this instance, return generic Dimensions
        return [
            {'Name': 'Filesystem', 'Value': '/not/found'},
            {'Name': 'InstanceId', 'Value': identifier},
            {'Name': 'MountPath', 'Value': kwargs.get('MountPath')},
        ]

    def get_alarm_name(self, identifier, **kwargs):

        return '{}_DiskSpaceUtilization:{}'.format(
            identifier,
            kwargs.get('MountPath'),
        )

    def _get_mount_path(self, dimensions):

        for dimension in dimensions:
            if dimension['Name'] == 'MountPath':
                return dimension['Value']


def setup(app):
    app.register_alarm(name='DiskSpaceUtilization',
                       alarm_class=DiskUtilizationAlarm())



from bluecanary.plugins import PluginBaseClass


class MemoryUtilizationAlarm(PluginBaseClass):
    def get_dimensions(self, identifier, **kwargs):
        return [{'Name': 'InstanceId', 'Value': identifier}]

    def get_alarm_name(self, identifier, **kwargs):
        return '{}_MemoryUtilization'.format(identifier)


def setup(app):
    app.register_alarm(name='MemoryUtilization', alarm_class=MemoryUtilizationAlarm())



from setuptools import setup, find_packages
import os
import sys

__version__ = '0.0.7'
__requirements__ = [
    "boto3==1.2.3",
    "click==6.2",
    "pluginbase==0.3",
    "PyYAML==3.11",
]


if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()


setup(
    name='bluecanary',
    version=__version__,
    packages=find_packages(),
    include_package_data=True,
    install_requires=__requirements__,
    entry_points='''
    [console_scripts]
    bluecanary=bluecanary.scripts.bluecanary:cli
    ''',
)
